API Reference
=============

This is the API reference for the :py:mod:`superneuromat` package.


.. currentmodule:: superneuromat

.. toctree::
   :maxdepth: 1
   :hidden:

   SNN
   Neuron
   Synapse

.. autosummary::
   :nosignatures:

   SNN
   Neuron
   Synapse

.. autosummary::
   :toctree: _gen/
   :recursive:

   ~accessor_classes.NeuronList
   ~accessor_classes.SynapseList
   neuromorphicmodel
   util
